@@ -6,7 +6,7 @@ use Mojo::Util qw(dumper);
 use DBI;
 use Carp qw(croak);
 
-our $VERSION  = '0.17';
+our $VERSION  = '0.18';
 
 use MojoX::Mysql::DB;
 use MojoX::Mysql::Result;
@@ -88,7 +88,6 @@ sub do {
 	$self->flush;
 
 	my $dbh = $self->db->id($id)->connect_master;
-	say $sql if (defined $ENV{'MOJO_MYSQL_DEBUG'} && $ENV{'MOJO_MYSQL_DEBUG'} == 1);
 	my $counter = $dbh->do($sql,undef,@_) or die $dbh->errstr;
 	my $insertid = int $dbh->{'mysql_insertid'};
 	return wantarray ? ($insertid,$counter) : $insertid;
@@ -129,8 +128,6 @@ sub query {
 		croak 'No connect server' if(ref $dbh ne 'DBI::db');
 	}
 
-	say $query if (defined $ENV{'MOJO_MYSQL_DEBUG'} && $ENV{'MOJO_MYSQL_DEBUG'} == 1);
-
 	if(defined $async){
 		my $sth = $dbh->prepare($query, {async=>1}) or croak $dbh->errstr;
 		$sth->execute(@_) or croak $dbh->errstr;
@@ -268,14 +265,6 @@ Return L<Mojo::Collection> object.
 
     $mysql->util->quote("test'test");
 
-=head2 quote_in
-
-    $mysql->util->quote_in("test'test");
-
-    # or
-
-    $mysql->util->quote_in(['test','test']);
-
 =head2 id
 
     $mysql->util->id;
@@ -286,10 +275,6 @@ Return id servers in L<Mojo::Collection> object.
 
 SEE ALSO L<Mojolicious::Plugin::Mysql>
 
-=head1 Mojolicious migration
-
-SEE ALSO L<Mojolicious::Command::sql>
-
 =head1 AUTHOR
 
 Kostya Ten, C<kostya@cpan.org>.
